==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Input/modplug/translations/modplug_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="47"/>
        <source>ModPlug Plugin</source>
        <translation>Plugin ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="53"/>
        <source>ModPlug Files</source>
        <translation>File ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>Tentang Plugin Audio ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="138"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Plugin Audio ModPlug Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="139"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="140"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Berdasarkan pada Plugin Modplug untuk Xmms</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="141"/>
        <source>Modplug Plugin developers:</source>
        <translation>Pengembang Plugin Modplug:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="142"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="143"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="144"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>Speed</source>
        <translation>Kecepatan</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="72"/>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="73"/>
        <location filename="../modplugmetadatamodel.cpp" line="94"/>
        <source>Samples</source>
        <translation>Sample</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="74"/>
        <location filename="../modplugmetadatamodel.cpp" line="103"/>
        <source>Instruments</source>
        <translation>Instrumen</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="75"/>
        <source>Patterns</source>
        <translation>Pola</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="76"/>
        <source>Channels</source>
        <translation>Saluran</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="108"/>
        <source>Comment</source>
        <translation>Komentar</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation>Setelan Plugin ModPlug</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation>Kualitas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation>Resolusi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation>16 bit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation>8 bit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation>Saluran</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation>Mono (downmix)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation>Resampling</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation>Nearest (lebih cepat)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation>Linear (cepat)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation>Spline (kualitas bagus)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap Fir (kualitas sangat tinggi)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation>Sampling Rate</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation>Efek</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation>Kumandang</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="202"/>
        <location filename="../settingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation>Kedalaman (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <location filename="../settingsdialog.ui" line="368"/>
        <location filename="../settingsdialog.ui" line="499"/>
        <location filename="../settingsdialog.ui" line="618"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="260"/>
        <location filename="../settingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation>Tunda (ms)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="292"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation>Bass Boost</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation>Banyaknya (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation>Jajaran (Hz)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="426"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation>Surround</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="551"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation>Preamp</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation>Catatan: Menyetel preamp terlalu tinggi mengakibatkan kliping!</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation>Lainnya</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="677"/>
        <source>General</source>
        <translation>Umum</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation>Gunakan namafile sebagai judul lagu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation>Peredam desis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation>Info cepat daftarmain</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation>Mainkan Amiga MOD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation>Mengikal</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation>Jangan ikal</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation>Ikal</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation>waktu(-waktu)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation>Ikal selamanya</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/modplug/translations/modplug_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="47"/>
        <source>ModPlug Plugin</source>
        <translation>Plugin ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="53"/>
        <source>ModPlug Files</source>
        <translation>File ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="119"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>Tentang Plugin Audio ModPlug</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="120"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Plugin Audio ModPlug Qmmp</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="121"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="122"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Berdasarkan pada Plugin Modplug untuk Xmms</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="123"/>
        <source>Modplug Plugin developers:</source>
        <translation>Pengembang Plugin Modplug:</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="124"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="125"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="126"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>File name</source>
        <translation>Nama file</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="142"/>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="147"/>
        <source>Length</source>
        <translation>Panjang</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="148"/>
        <source>Speed</source>
        <translation>Kecepatan</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="149"/>
        <source>Tempo</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="150"/>
        <location filename="../modplugmetadatamodel.cpp" line="171"/>
        <source>Samples</source>
        <translation>Sample</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="151"/>
        <location filename="../modplugmetadatamodel.cpp" line="180"/>
        <source>Instruments</source>
        <translation>Instrumen</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="152"/>
        <source>Patterns</source>
        <translation>Pola</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="153"/>
        <source>Channels</source>
        <translation>Saluran</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="185"/>
        <source>Comment</source>
        <translation>Komentar</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation>Setelan Plugin ModPlug</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation>Kualitas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation>Resolusi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation>16 bit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation>8 bit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation>Saluran</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation>Mono (downmix)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation>Resampling</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation>Nearest (lebih cepat)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation>Linear (cepat)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation>Spline (kualitas bagus)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap Fir (kualitas sangat tinggi)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation>Sampling Rate</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation>Efek</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation>Kumandang</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="202"/>
        <location filename="../settingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation>Kedalaman (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <location filename="../settingsdialog.ui" line="368"/>
        <location filename="../settingsdialog.ui" line="499"/>
        <location filename="../settingsdialog.ui" line="618"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="260"/>
        <location filename="../settingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation>Tunda (ms)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="292"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation>Bass Boost</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation>Banyaknya (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation>Jajaran (Hz)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="426"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation>Surround</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="551"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation>Preamp</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation>Catatan: Menyetel preamp terlalu tinggi mengakibatkan kliping!</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation>Lainnya</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="677"/>
        <source>General</source>
        <translation>Umum</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation>Gunakan namafile sebagai judul lagu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation>Peredam desis</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation>Info cepat daftarmain</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation>Mainkan Amiga MOD</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation>Mengikal</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation>Jangan ikal</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation>Ikal</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation>waktu(-waktu)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation>Ikal selamanya</translation>
    </message>
</context>
</TS>
